@@ -34,6 +34,9 @@
 #include <unistd.h>
 #include <getopt.h>
 #endif
+#ifndef HAVE_GETOPT_LONG
+#include "getopt_win.h"
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -435,11 +438,7 @@ int main(int argc, char **argv)
    }
    else 
    {
-#if defined WIN32 || defined _WIN32
       fin = fopen(inFile, "rb");
-#else
-      fin = fopen(inFile, "r");
-#endif
       if (!fin)
       {
          perror(inFile);
@@ -553,11 +552,7 @@ int main(int argc, char **argv)
    }
    else 
    {
-#if defined WIN32 || defined _WIN32
       fout = fopen(outFile, "wb");
-#else
-      fout = fopen(outFile, "w");
-#endif
       if (!fout)
       {
          perror(outFile);
@@ -567,7 +562,7 @@ int main(int argc, char **argv)
    }
 
 
-   /*Write header (format will change)*/
+   /*Write header*/
    {
 
       op.packet = (unsigned char *)speex_header_to_packet(&header, (int*)&(op.bytes));
@@ -666,12 +661,12 @@ int main(int argc, char **argv)
       id++;
       /*Encode current frame*/
       if (chan==2)
-         speex_encode_stereo(input, frame_size, &bits);
+         speex_encode_stereo_int(input, frame_size, &bits);
 
       if (preprocess)
          speex_preprocess(preprocess, input, NULL);
 
-      speex_encode(st, input, &bits);
+      speex_encode_int(st, input, &bits);
       
       if (print_bitrate) {
          int tmp;
